"use strict";
/**
 * Copyright (c) Microsoft Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.installInspectorController = void 0;
const browserContext_1 = require("../browserContext");
const utils_1 = require("../../utils/utils");
const consoleApiSupplement_1 = require("./consoleApiSupplement");
const recorderSupplement_1 = require("./recorderSupplement");
const page_1 = require("../page");
function installInspectorController() {
    browserContext_1.contextListeners.add(new InspectorController());
}
exports.installInspectorController = installInspectorController;
class InspectorController {
    async onContextCreated(context) {
        if (utils_1.isDebugMode()) {
            const consoleApi = new consoleApiSupplement_1.ConsoleApiSupplement(context);
            await consoleApi.install();
            recorderSupplement_1.RecorderSupplement.getOrCreate(context, 'debug', {
                language: 'javascript',
                terminal: true,
            });
            context.on(browserContext_1.BrowserContext.Events.Page, (page) => {
                page.on(page_1.Page.Events.Console, (message) => context.emit(browserContext_1.BrowserContext.Events.StdOut, message.text() + '\n'));
            });
        }
    }
    async onContextWillDestroy(context) { }
    async onContextDidDestroy(context) { }
}
//# sourceMappingURL=inspectorController.js.map